// Copyright (C) 2002 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#ifndef __GLOBALFIELD_HH
#define __GLOBALFIELD_HH

#include <kw_constants.h>

class Grid;
class Vector;

enum Representation { NONE, NODAL, CELL, CONSTANT, FUNCTION };
 
class GlobalField{
  
public:

  GlobalField(Grid *grid, real constant);
  GlobalField(Grid *grid, Vector *x, int nvd = 1);
  GlobalField(Grid *grid, const char *field);
  
  ~GlobalField();

  void AttachGrid( Grid* g );
  
  int GetNoDof();
  int GetVectorDim();

  int GetDim(int cell);

  void GetLocalDof(int cell, real t, real *local_dofs, int component = 0);

  Representation GetRep() { return representation; }  

  real GetCellValue(int cell, int component);
  real GetCellValue(int cell);  
  real GetNodalValue(int nod, int component);
  real GetNodalValue(int nod);
  real GetDofValue(int nod, int component);
  real GetDofValue(int nod);
  real GetConstantValue(); 
  
private:
  
  Grid* grid;
  
  int no_dof;
  int nvd;

  Representation representation;

  Vector *dof_values;
  Vector *cell_values;
  real constant;    
  real (*function)(real x, real y, real z, real t);
  
};

#endif
