// Copyright (C) 2002 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#include <dolfin.h>

dolfin_bc my_bc(real x, real y, real z, int node, int component);

int main(int argc, char **argv)
{
  // Set problem
  dolfin_set_problem("conv-diff");
  
   // Set parameters
  dolfin_set_parameter("problem description", "Convection-Diffusion equation on the unit cube");
  dolfin_set_parameter("grid file",           "../../../data/grids/tetgrid_8_8_8.inp");
  dolfin_set_parameter("output file prefix",  "conv-diff");

  // Set boundary conditions
  dolfin_set_boundary_conditions(my_bc);
  
  dolfin_set_parameter("start time", 0.0);
  dolfin_set_parameter("final time", 1.0);

  // Initialize dolfin
  dolfin_init(argc,argv);

  // Save parameters
  dolfin_save_parameters();

  // Solve the problem
  dolfin_solve();
  
  // Finished
  dolfin_end();
  
  return 0;
}

dolfin_bc my_bc(real x, real y, real z, int node, int component)
{
  dolfin_bc bc;
  
  if ( x == 0.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }
  if ( x == 1.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }

  /*
  if ( y == 0.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }
  if ( y == 1.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }
  */

  /*
  if ( z == 0.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }
  if ( z == 1.0 ){
	 bc.type = dirichlet;
	 bc.val  = 0.0;
  }
  */

  return bc;
}
